summaryrefslogtreecommitdiff
path: root/passlib/exc.py
diff options
context:
space:
mode:
Diffstat (limited to 'passlib/exc.py')
-rw-r--r--passlib/exc.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/passlib/exc.py b/passlib/exc.py
index 755c7dc..29ef8af 100644
--- a/passlib/exc.py
+++ b/passlib/exc.py
@@ -310,8 +310,8 @@ def ExpectedTypeError(value, expected, param):
return TypeError("%s must be %s, not %s" % (param, expected, name))
def ExpectedStringError(value, param):
- """error message when param was supposed to be unicode or bytes"""
- return ExpectedTypeError(value, "unicode or bytes", param)
+ """error message when param was supposed to be str or bytes"""
+ return ExpectedTypeError(value, "str or bytes", param)
#------------------------------------------------------------------------
# hash/verify parameter errors